/**
 * @file m13_ra6m3_ek_adc.h
 * @brief m13_ra6m3_ek adc BSP
 *
 * @section License
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Copyright (C) 2020-2021 M13DESIGN SARL. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @author M13DESIGN SARL (www.m13design.fr)
 * @version 1.0.0
 **/

#ifndef _M13_RA6M3_EK_ADC_H
#define _M13_RA6M3_EK_ADC_H

// Dependencies
#include "r_ioport.h"
#include "m13_ra6m3_ek_status.h"

typedef enum
{
    BSP_ADC_CHANNEL_0           = 0,       ///< ADC channel 0
    BSP_ADC_CHANNEL_1           = 1,       ///< ADC channel 1
    BSP_ADC_CHANNEL_2           = 2,       ///< ADC channel 2
    BSP_ADC_CHANNEL_3           = 3,       ///< ADC channel 3
    BSP_ADC_CHANNEL_4           = 4,       ///< ADC channel 4
    BSP_ADC_CHANNEL_5           = 5,       ///< ADC channel 5
    BSP_ADC_CHANNEL_6           = 6,       ///< ADC channel 6
    BSP_ADC_CHANNEL_7           = 7,       ///< ADC channel 7
    BSP_ADC_CHANNEL_8           = 8,       ///< ADC channel 8
    BSP_ADC_CHANNEL_9           = 9,       ///< ADC channel 9
    BSP_ADC_CHANNEL_10          = 10,      ///< ADC channel 10
    BSP_ADC_CHANNEL_11          = 11,      ///< ADC channel 11
    BSP_ADC_CHANNEL_12          = 12,      ///< ADC channel 12
    BSP_ADC_CHANNEL_13          = 13,      ///< ADC channel 13
    BSP_ADC_CHANNEL_14          = 14,      ///< ADC channel 14
    BSP_ADC_CHANNEL_15          = 15,      ///< ADC channel 15
    BSP_ADC_CHANNEL_16          = 16,      ///< ADC channel 16
    BSP_ADC_CHANNEL_17          = 17,      ///< ADC channel 17
    BSP_ADC_CHANNEL_18          = 18,      ///< ADC channel 18
    BSP_ADC_CHANNEL_19          = 19,      ///< ADC channel 19
    BSP_ADC_CHANNEL_20          = 20,      ///< ADC channel 20
    BSP_ADC_CHANNEL_21          = 21,      ///< ADC channel 21
    BSP_ADC_CHANNEL_22          = 22,      ///< ADC channel 22
    BSP_ADC_CHANNEL_23          = 23,      ///< ADC channel 23
    BSP_ADC_CHANNEL_24          = 24,      ///< ADC channel 24
    BSP_ADC_CHANNEL_25          = 25,      ///< ADC channel 25
    BSP_ADC_CHANNEL_26          = 26,      ///< ADC channel 26
    BSP_ADC_CHANNEL_27          = 27,      ///< ADC channel 27
    BSP_ADC_CHANNEL_DUPLEX_A    = 50,      ///< Data duplexing register A
    BSP_ADC_CHANNEL_DUPLEX_B    = 51,      ///< Data duplexing register B
    BSP_ADC_CHANNEL_DUPLEX      = -4,      ///< Data duplexing register
    BSP_ADC_CHANNEL_TEMPERATURE = -3,      ///< Temperature sensor output
    BSP_ADC_CHANNEL_VOLT        = -2,      ///< Internal reference voltage
} bsp_adc_channel_t;

typedef enum
{
    BSP_ADC_MASK_OFF         = (0U),                                   ///< No channels selected
    BSP_ADC_MASK_CHANNEL_0   = (1U << 0U),                             ///< Channel 0 mask
    BSP_ADC_MASK_CHANNEL_1   = (1U << 1U),                             ///< Channel 1 mask
    BSP_ADC_MASK_CHANNEL_2   = (1U << 2U),                             ///< Channel 2 mask
    BSP_ADC_MASK_CHANNEL_3   = (1U << 3U),                             ///< Channel 3 mask
    BSP_ADC_MASK_CHANNEL_4   = (1U << 4U),                             ///< Channel 4 mask
    BSP_ADC_MASK_CHANNEL_5   = (1U << 5U),                             ///< Channel 5 mask
    BSP_ADC_MASK_CHANNEL_6   = (1U << 6U),                             ///< Channel 6 mask
    BSP_ADC_MASK_CHANNEL_7   = (1U << 7U),                             ///< Channel 7 mask
    BSP_ADC_MASK_CHANNEL_8   = (1U << 8U),                             ///< Channel 8 mask
    BSP_ADC_MASK_CHANNEL_9   = (1U << 9U),                             ///< Channel 9 mask
    BSP_ADC_MASK_CHANNEL_10  = (1U << 10U),                            ///< Channel 10 mask
    BSP_ADC_MASK_CHANNEL_11  = (1U << 11U),                            ///< Channel 11 mask
    BSP_ADC_MASK_CHANNEL_12  = (1U << 12U),                            ///< Channel 12 mask
    BSP_ADC_MASK_CHANNEL_13  = (1U << 13U),                            ///< Channel 13 mask
    BSP_ADC_MASK_CHANNEL_14  = (1U << 14U),                            ///< Channel 14 mask
    BSP_ADC_MASK_CHANNEL_15  = (1U << 15U),                            ///< Channel 15 mask
    BSP_ADC_MASK_CHANNEL_16  = (1U << 16U),                            ///< Channel 16 mask
    BSP_ADC_MASK_CHANNEL_17  = (1U << 17U),                            ///< Channel 17 mask
    BSP_ADC_MASK_CHANNEL_18  = (1U << 18U),                            ///< Channel 18 mask
    BSP_ADC_MASK_CHANNEL_19  = (1U << 19U),                            ///< Channel 19 mask
    BSP_ADC_MASK_CHANNEL_20  = (1U << 20U),                            ///< Channel 20 mask
    BSP_ADC_MASK_CHANNEL_21  = (1U << 21U),                            ///< Channel 21 mask
    BSP_ADC_MASK_CHANNEL_22  = (1U << 22U),                            ///< Channel 22 mask
    BSP_ADC_MASK_CHANNEL_23  = (1U << 23U),                            ///< Channel 23 mask
    BSP_ADC_MASK_CHANNEL_24  = (1U << 24U),                            ///< Channel 24 mask
    BSP_ADC_MASK_CHANNEL_25  = (1U << 25U),                            ///< Channel 25 mask
    BSP_ADC_MASK_CHANNEL_26  = (1U << 26U),                            ///< Channel 26 mask
    BSP_ADC_MASK_CHANNEL_27  = (1U << 27U),                            ///< Channel 27 mask
    BSP_ADC_MASK_TEMPERATURE = (1U << 28UL),                           ///< Temperature sensor channel mask
    BSP_ADC_MASK_VOLT        = (1U << 29UL),                           ///< Voltage reference channel mask
    BSP_ADC_MASK_SENSORS     = (BSP_ADC_MASK_VOLT | BSP_ADC_MASK_VOLT), ///< All sensor channel mask
} bsp_adc_mask_t;

// macro definitions

// BSP Functions

void bsp_adc_io_init (void);
bsp_status_t bsp_adc_init (bsp_adc_channel_t adc_channel);
uint16_t bsp_adc_get_level (bsp_adc_channel_t adc_channel);
bsp_status_t bsp_adc_deinit (bsp_adc_channel_t adc_channel);

#endif

