/**
 * @file m13_ra6m3_ek_led.c
 * @brief M13-RA6M3-EK led BSP
 *
 * @section License
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Copyright (C) 2020-2021 M13DESIGN SARL. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @author M13DESIGN SARL (www.m13design.fr)
 * @version 1.0.0
 **/

#include "m13_ra6m3_ek_led.h"
#include "m13_ra6m3_ek_pinout.h"


//Led IOPORT structure
static ioport_instance_ctrl_t led_pin_ctrl;

/**
 * @name       bsp_led_io_init 
 * @brief      Initialize and configure the led pins
 * @param[in]  None
 * @return     Error code (see #ErrorCode enumeration)
 **/
void bsp_led_io_init (void)
{
    ioport_cfg_t led_pin_cfg;

    led_pin_cfg.number_of_pins = sizeof(m13_ra6m3_ek_led_pin_data)/sizeof(ioport_pin_cfg_t);
    led_pin_cfg.p_pin_cfg_data = &m13_ra6m3_ek_led_pin_data[0];

    //Configure led pins
    R_IOPORT_Open(&led_pin_ctrl, &led_pin_cfg);
}

/**
 * @name       bsp_led_on 
 * @brief      Turn on the requested led
 * @param[in]  led_number : The board led Id
 * @return     None
 **/
void bsp_led_on (bsp_led_channel_t led_number)
{
    //Turn on led
    R_IOPORT_PinWrite(&led_pin_ctrl, led_number, BSP_IO_LEVEL_HIGH);
}

/**
 * @name       bsp_led_off 
 * @brief      Turn off the requested led
 * @param[in]  led_number : The board led Id
 * @return     None
 **/
void bsp_led_off (bsp_led_channel_t led_number)
{
    //Turn off led
    R_IOPORT_PinWrite(&led_pin_ctrl, led_number, BSP_IO_LEVEL_LOW);
}

/**
 * @name       bsp_led_get_state 
 * @brief      Get the Led state
 * @param[in]  led_number : The board led Id
 * @return     None
 **/
bsp_led_state_t bsp_led_get_state (bsp_led_channel_t led_number)
{
    bsp_io_level_t  led_state;

    R_IOPORT_PinRead(&led_pin_ctrl, led_number, &led_state);

    return led_state;
}

